@@ -41,7 +41,7 @@ class Geometry:
         path_to_cst_file = os.path.abspath(f"{path_to_CST_project}\{name}.cst")
         path_to_script = os.path.abspath('basic_script/script.bas')
 
-        with open('basic_script/script.bas', 'r') as f:
+        with open(path_to_script, 'r') as f:
             lines = f.readlines()
             lines[1] = f'geometry_file = \"{path_to_geometry}\"\n'
             lines[-4] = f'proj.SaveAs \"{path_to_cst_file}\", True\n'
